# value displayed in the object history table if a comment is not viewable
HISTORY_COMMENT_NOT_VIEWABLE = u"<span class='discreet'>Access to this comment is restricted.</span>"

# value displayed in the object history table if a revision is not viewable
HISTORY_REVISION_NOT_VIEWABLE = u"<span class='discreet'>Access to this revision is restricted.</span>"

# comments that will be ignored regarding the history link highlight when comment in last event
DEFAULT_IGNORABLE_COMMENTS = (HISTORY_COMMENT_NOT_VIEWABLE, )
